import Link from "next/link";

const siteName = process.env.NEXT_PUBLIC_SITE_NAME || "Your Site Name";
const currentYear = new Date().getFullYear();

const FooterSection: React.FC = () => {
  return (
    <footer className="mt-auto w-full py-10 px-4 sm:px-6 lg:px-8 mx-auto">
      <div className="max-w-7xl relative pt-6 lg:pt-0 px-4 sm:px-6 lg:px-8 mx-auto">
        <div className="grid grid-cols-1 lg:grid-cols-3 gap-6 mb-10">
          <div className="lg:col-span-1">
            <Link
              className="flex-none text-xl font-semibold dark:text-white"
              href="#"
              aria-label="Brand"
            >
              {siteName}
            </Link>
            <p className="mt-3 text-xs sm:text-sm text-gray-600 dark:text-neutral-400">
              Our exchange uses charting technology provided by TradingView, a
              global platform where you can{" "}
              <Link
                className="inline-flex items-center gap-x-1.5 text-blue-600 decoration-2 hover:underline font-medium dark:text-blue-500"
                href="https://www.tradingview.com/markets/cryptocurrencies/prices-all/"
              >
                watch cryptocurrency prices
              </Link>
              , analyze market movements, and prepare for trades with the latest
              news and insights from fellow traders.
            </p>
          </div>
          <div className="lg:col-span-2 grid grid-cols-2 md:grid-cols-3 gap-6">
            <div>
              <h4 className="text-xs font-semibold text-gray-900 uppercase dark:text-neutral-100">
                Company
              </h4>
              <div className="mt-3 grid space-y-3 text-sm">
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="#"
                  >
                    About us
                  </Link>
                </p>
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="/blog"
                  >
                    Blog
                  </Link>
                </p>
              </div>
            </div>
            <div>
              <h4 className="text-xs font-semibold text-gray-900 uppercase dark:text-neutral-100">
                Developers
              </h4>
              <div className="mt-3 grid space-y-3 text-sm">
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="/user/support/ticket"
                  >
                    Help & Support
                  </Link>
                </p>
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="/api/docs/"
                  >
                    Api
                  </Link>
                </p>
              </div>
            </div>
            <div>
              <h4 className="text-xs font-semibold text-gray-900 uppercase dark:text-neutral-100">
                Legal
              </h4>
              <div className="mt-3 grid space-y-3 text-sm">
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="/terms-and-conditions"
                  >
                    Terms & Conditions
                  </Link>
                </p>
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="/privacy-policy"
                  >
                    Privacy Policy
                  </Link>
                </p>
                <p>
                  <Link
                    className="inline-flex gap-x-2 text-gray-600 hover:text-gray-800 dark:text-neutral-400 dark:hover:text-neutral-200"
                    href="/cookies"
                  >
                    Cookies Policy
                  </Link>
                </p>
              </div>
            </div>
          </div>
        </div>
        <div className="pt-5 mt-5 border-t border-gray-200 dark:border-neutral-700">
          <div className="sm:flex sm:justify-between sm:items-center">
            <p className="mt-1 text-xs sm:text-sm text-gray-600 dark:text-neutral-400">
              © {currentYear} {siteName}. All rights reserved.
            </p>
          </div>
        </div>
      </div>
    </footer>
  );
};

export default FooterSection;
